@@ -1,7 +1,7 @@
 import math
 import random
 
-from eqsmart.main.consumer import Consumer
+from eqsmart.main.consumer import Consumer, fail_server_list
 from eqlink.components.remote_server import remote_server
 import json
 
@@ -58,5 +58,9 @@ class RemoteCall:
             'BUF_SIZE': 1024
         }
         print('[eqsmart] 远程调用', provider_conf, protocol)
-        remote_call = Consumer(provider_conf).func_call_int(protocol)
+        try:
+            remote_call = Consumer(provider_conf).func_call_int(protocol)
+        except Exception as e:
+            fail_server_list.append({'IP': provider_conf['IP'], 'PORT': provider_conf['PORT']})
+            print('[eqsmart] 远程调用失败！', e)
         return json.loads(remote_call)
